@@ -1530,29 +1530,31 @@ c
       INCLUDE 'Parametres.f'
       character*132 fichiers(*)
       integer idir(*),lfichiers(*)
-      parameter(numext=41)
+      parameter(numext=45)
       character*12 ext(numext)
       integer     lext(numext)
       data ext / '.bit','.charge','.def_max','.def_min'
      a          ,'.defor11','.defor22','.defor33'
      b          ,'.defor23','.defor31','.defor12','.depcont','.depimp'
-     c          ,'.depl','.depmod','.effcontact','.en','.enp'
-     d          ,'.errcont','.errdep','.for','.force','.forces'
+     c          ,'.depl','.depmod','.effcontact','.effdep','.en','.enp'
+     d          ,'.errcont','.errdep','.fcout','.for','.force','.forces'
      e          ,'.maxmises','.maxmisesp','.mises','.misesp','.mode'
      f          ,'.psi','.second','.solu'
      g          ,'.stres11','.stres22','.stres33'
      h          ,'.stres23','.stres31','.stres12'
-     i          ,'.str_max','.theta','.thetap','.v','.xd3d' /
+     i          ,'.str_max','.theta','.thetap','.v','.vit','.vitnod'
+     j          ,'.xd3d' /
       data lext / 4,7,8,8
      a          , 8,8,8
      b          , 8,8,8,8,8
-     c          , 5,7,11,3,4   
-     d          , 8,7,4,6,7 
+     c          , 5,7,11,7,3,4   
+     d          , 8,7,6,4,6,7 
      e          , 9,10,6,7,5
      f          , 4,7,5
      g          , 8,8,8
      h          , 8,8,8
-     i          , 8,6,7,2,5 /
+     i          , 8,6,7,2,4,7
+     j          , 5 /
 c
       ishiftliste = 0
       nfich = 0
