@@ -1,3 +1,4 @@
+#include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
@@ -20,8 +21,17 @@
 
 #define MAXCOURT 0xFFFF
 
+/*
 #define X_POS 0
 #define Y_POS 0
+*/
+/* 
+Pour eviter les bandeaux et autres icones - voir comment le paramtrer
+par l'utilisateur (argument ligne de commande ?)
+*/
+
+#define X_POS 100
+#define Y_POS 50
 
 #ifndef F77_NO_UNDER_SCORE
 #define drawarc drawarc_
