@@ -1085,7 +1085,7 @@ C
       ELSE
         YYLAR = XLARG*HYA4/HXA4
       ENDIF
-      IF (IPOST.EQ.1.OR.ICADPS.GT.0) THEN
+      IF ((IPOST.EQ.1.OR.ICADPS.GT.0).AND.IDEPOUILLE.LE.1) THEN
         IF (ICARRE.EQ.1) THEN
           XXLAR2 = XLARG*(2.*HYA4/HXA4-1.)
         ELSE
@@ -1094,8 +1094,8 @@ C
       ELSE
         XXLAR2 = XLARG
       ENDIF
-      IF (IPOST.EQ.1) THEN
-        XXLAR3 = XLARG+YYLAR*.6
+      IF (IPOST.EQ.1.and.idepouille.eq.0) THEN
+        XXLAR3 = XLARG+YYLAR*0.6
       ELSE
         XXLAR3 = XLARG
       ENDIF
@@ -1107,13 +1107,13 @@ C
       YDMIN = YCUR-YYLAR
       YDMAX = YCUR+YYLAR
       IF (IOPT.EQ.0) THEN
-        IF (IPOST.EQ.1) THEN
-          YDMI2  = YDMIN - .03*(YDMAX-YDMIN)
+        IF (IPOST.EQ.1.AND.IDEPOUILLE.EQ.0) THEN
+          YDMI2 = YDMIN - 0.03*(YDMAX-YDMIN)
           CALL GSUWIN(XDMIN,XDMA2,YDMI2,YDMAX)
           CALL GSQWIN(XDMIN,XDMA2,YDMI2,YDMAX)
-          YDMIN = YDMI2 + .03*(YDMAX-YDMI2)/1.03
+          YDMIN = YDMI2 + 0.03*(YDMAX-YDMI2)/1.03
         ELSE
-          YDMI2  = YDMIN
+          YDMI2 = YDMIN
           CALL GSUWIN(XDMIN,XDMA2,YDMI2,YDMAX)
           CALL GSQWIN(XDMIN,XDMA2,YDMI2,YDMAX)
           YDMIN = YDMI2
@@ -1122,8 +1122,16 @@ C
         IX1 = IVRAIECOORD(XDMAX)
         PIXEL = (XDMAX-XHELP)/REAL(IABS(IX0-IX1))
       ENDIF
-      XDMAX = XDMA2 - .5*XCOCO*(YDMAX-YDMIN)
-      XHELP = XDMIN + .5*XCOTE3*(YDMAX-YDMIN)
-      XINFO = XHELP + .5*(YDMIN-YDMI2)
-      YINFO = YDMI2 + .3*(YDMIN-YDMI2)
+      IF (IDEPOUILLE.LE.1) THEN
+        XDMAX = XDMA2 - 0.5*XCOCO*(YDMAX-YDMIN)
+      ELSE
+        XDMAX = XDMA2
+      ENDIF
+      IF (IDEPOUILLE.EQ.0) THEN
+        XHELP = XDMIN + 0.5*XCOTE3*(YDMAX-YDMIN)
+      ELSE
+        XHELP = XDMIN
+      ENDIF
+      XINFO = XHELP + 0.5*(YDMIN-YDMI2)
+      YINFO = YDMI2 + 0.3*(YDMIN-YDMI2)
       END
