@@ -2,14 +2,14 @@
       INCLUDE 'com_coor.f'
       INCLUDE 'com_faces.f'
       INCLUDE 'com_options.f'
-      PARAMETER (NBIMAX=2000)
+      PARAMETER (NBIMAX=9999)
       DIMENSION RSMOOTH(3,3,NBIMAX),RBID(3,3)
       CHARACTER*8192 LISTE,LISTE_S
       CHARACTER*128 IMAGES,FICLEC,FICPOST,FICLEC2,FICPOST2,CBIDON
      &             ,GIFSICLE
       CHARACTER*13  TS
       CHARACTER*11  RVB
-      CHARACTER*7   CNUM
+      CHARACTER*8   CNUM
       LOGICAL*4     GEOM,TROUVE
       DIMENSION ROUGE(0:15),VERT(0:15),BLEU(0:15)
 C
@@ -31,6 +31,8 @@ C
       VMAMA = VMAX
       ISUSU = 0
       FACEXA0 = FACEXA
+      facexaloc = FACEXA
+      facfacex = 1.
       IDEFPS0 = IDEFPS
       FAC1 = 0.
       FAC2 = 0.
@@ -231,7 +233,7 @@ C
         IF (ICOURB.GT.0) THEN
           IF (IEXAG.NE.0.AND.NOM_VIT(LONVIT-4:LONVIT).eq.'.depl') THEN
             IF (ILANG.EQ.0) THEN
-              CALL LIENTIER('Lect. de plusieurs fich. '//
+              CALL LIENTIER('Lecture de plusieurs fichiers '//
      &'(2:vec+scal, 1:oui, 0:non, -1:spcial dforme) ?'
      &             ,0,IMULFI)
             ELSE
@@ -243,7 +245,7 @@ C
           ELSEIF(IEXAG.NE.0
      &           .AND.NOM_VIT(LONVIT-4:LONVIT).eq.'.mode') THEN
             IF (ILANG.EQ.0) THEN
-              CALL LIENTIER('Lect. de plusieurs fich. '//
+              CALL LIENTIER('Lecture de plusieurs fichier '//
      &           '(2:vec+scal, 1:oui, 0:non, -1:spcial mode propre) ?'
      &             ,0,IMULFI)
             ELSE
@@ -406,26 +408,40 @@ Cfj              ENDDO
 C ???? (7/2002)
 Cfj            IF (ISO.NE.0.AND.ISOBID.NE.0
 Cfj     &           .AND.NOM_ISO(1:2).EQ.'$'//NOM_FICH(1:1)) THEN
-            IF (ISO.NE.0.and.imulfi.gt.0) THEN
+            IF (ISO.NE.0.and.IMULFI.GT.0) THEN
               IF (ILANG.EQ.0) THEN
+Cfj                PRINT*,
+Cfj     &'Pour utiliser les isovaleurs fixes allant du min au max des'
+Cfj                PRINT*,
+Cfj     &'valeurs trouves sur l''ensemble des fichiers, rpondez :'
+Cfj                PRINT*,
+Cfj     &'"Bornes des isovaleurs fixes", puis donnez 2 valeurs gales.'
                 CALL LIENTIER(
-     &  'Bornes des isovaleurs fixes (0) ou variables (1) ?',0,IFIXB)
+     &'Bornes des isovaleurs fixes (0) ou variables (1) ?',0,IFIXB)
               ELSE
+Cfj                PRINT*,
+Cfj     &'To use contour plots with fixed bound, from the min to the max'
+Cfj                PRINT*,
+Cfj     &'value found in all data files involved in the movie, answer:'
+Cfj                PRINT*,
+Cfj     &'"Bounds for contour plot fixed", then enter 2 equal values.'
                 CALL LIENTIER(
-     &  'Bounds for contour plot fixed (0) or variable (1) ?',0,IFIXB)
+     &'Bounds for contour plot fixed (0) or variable (1) ?',0,IFIXB)
               ENDIF
               IF (IFIXB.EQ.0) THEN
                 IF (ILANG.EQ.0) THEN
                   CALL LI2REEL1('Bornes des isovaleurs ?',0,VMIMI,VMAMA)
                 ELSE
                   CALL LI2REEL1('Bounds for contour plot ?',0
-     &                 ,VMIMI,VMAMA)
+     &                         ,VMIMI,VMAMA)
                 ENDIF
                 IF (VMIMI.GT.VMAMA) THEN
                   CALL ECHR(VMIMI,VMAMA)
                 ELSEIF(VMIMI.EQ.VMAMA) THEN
-                  IFIXB = 1
+                  IFIXB = 2
                 ENDIF
+              ELSE
+                IFIXB = 1
               ENDIF
             ENDIF
           ENDIF
@@ -637,16 +653,44 @@ Cfj            ENDIF
                 CALL EXAGERE(DFACX,DFACY,DFACZ,IOPTEXA)
               ELSE
                 IDEPL = 0
+                call lientier(
+     &  'Facteur d''exagration fixe (0) ou variable (1) ?',0,ifacex)
+                if (ifacex.eq.0) then
+                  call lireel1(
+     &  'Facteur d''exageration pour le film ?',0,facexaloc)
+                else
+                  call lireel1(
+     &  'Facteur d''exageration initial pour le film ?',0,facexaloc)
+                  call lireel1(
+     &  'coefficient multiplicatif d''une image  l''autre ?',0
+     &                 ,facfacex)
+                endif
+                DFACX = facexaloc-FACEXA
+                DFACY = facexaloc-FACEXA
+                DFACZ = facexaloc-FACEXA
+                CALL EXAGERE(DFACX,DFACY,DFACZ,IOPTEXA)
               ENDIF
             ENDIF
           ENDIF
           IF (ISO.NE.0) THEN
             IF (ILANG.EQ.0) THEN
+              PRINT*,
+     &'Pour utiliser les isovaleurs fixes allant du min au max des'
+              PRINT*,
+     &'valeurs trouves sur l''ensemble des fichiers, rpondez :'
+              PRINT*,
+     &'"Bornes des isovaleurs fixes", puis donnez 2 valeurs gales.'
               CALL LIENTIER(
-     &  'Bornes des isovaleurs fixes (0) ou variables (1) ?',0,IFIXB)
+     &'Bornes des isovaleurs fixes (0) ou variables (1) ?',0,IFIXB)
             ELSE
+              PRINT*,
+     &'To use contour plots with fixed bound, from the min to the max'
+              PRINT*,
+     &'value found in all data files involved in the movie, answer:'
+              PRINT*,
+     &'"Bounds for contour plot fixed", then enter 2 equal values.'
               CALL LIENTIER(
-     &  'Bounds for contour plot fixed (0) or variable (1) ?',0,IFIXB)
+     &'Bounds for contour plot fixed (0) or variable (1) ?',0,IFIXB)
             ENDIF
             IF (IFIXB.EQ.0) THEN
               IF (ILANG.EQ.0) THEN
@@ -657,8 +701,51 @@ Cfj            ENDIF
               IF (VMIMI.GT.VMAMA) THEN
                 CALL ECHR(VMIMI,VMAMA)
               ELSEIF(VMIMI.EQ.VMAMA) THEN
-                IFIXB = 1
+                IFIXB = 2
+                VMIMI = BIG
+                VMAMA = -BIG
+                DO I=1,NBIMA
+                  CALL ECCNUM(INUM0+(I-1)*ISTEP,IDERN,CNUM,LC)
+                  IF (IMULFI.EQ.2) THEN
+                    IF (LFP2.LE.0) THEN
+                      LBID = LF2+LC
+                      CBIDON(1:LBID) = FICLEC2(1:LF2)//CNUM(1:LC)
+                    ELSE
+                      LBID = LF2+LC+LFP2
+                      CBIDON(1:LBID) = FICLEC2(1:LF2)//CNUM(1:LC)
+     &                     //FICPOST2(1:LFP2)
+                    ENDIF
+                  ELSE
+                    IF (LFP.LE.0) THEN
+                      LBID = LF+LC
+                      CBIDON(1:LBID) = FICLEC(1:LF)//CNUM(1:LC)
+                    ELSE
+                      LBID = LF+LC+LFP
+                      CBIDON(1:LBID) = FICLEC(1:LF)//CNUM(1:LC)
+     &                                             //FICPOST(1:LFP)
+                    ENDIF
+                  ENDIF
+                  OPEN(2,FILE=CBIDON(1:LBID),STATUS='OLD',IOSTAT=IERR)
+                  IF (IERR.NE.0) THEN
+                    IF (ILANG.EQ.0) THEN
+                      PRINT*,'*** Problme  l''ouverture de '
+     &                     //CBIDON(1:LBID)
+                    ELSE
+                      PRINT*,'*** Troubles opening '//CBIDON(1:LBID)
+                    ENDIF
+                  ENDIF
+                  CALL LIISO(ICLAS,CBIDON,LBID,IRC,ICONTR,IDEPL,IVAL)
+                  VMIMI = MIN(VMIMI,VMIN)
+                  VMAMA = MAX(VMAMA,VMAX)
+                ENDDO
+                IF (ILANG.EQ.0) THEN
+                  PRINT*,'Bornes trouves =',VMIMI,VMAMA
+                ELSE
+                  PRINT*,'Observed bounds =',VMIMI,VMAMA
+                ENDIF
               ENDIF
+            ELSE
+              IFIXB = 1
             ENDIF
           ENDIF
         ENDIF
@@ -738,7 +825,7 @@ C
       IYIMAGE = IPIXY
       IPOST = -2
       IF (IPROGRE.GT.0) IPROGRE = -IPROGRE
-      IF (IFIXB.NE.0.AND.ISO.NE.0.AND.NBIMA.GT.1.AND.IFORMAT.GE.0) THEN
+      IF (IFIXB.EQ.1.AND.ISO.NE.0.AND.NBIMA.GT.1.AND.IFORMAT.GE.0) THEN
         IF (ILANG.EQ.0) THEN
           PRINT*,
      &    'On cre '//IMAGES(1:LIM)//'.bornes pour stocker les bornes'
@@ -817,7 +904,7 @@ Cfj     &           .AND.NOM_ISO(1:2).EQ.'$'//NOM_FICH(1:1)) CALL MYISO
               DDD  = DDD+DFAC
               DDD0 = DDD0+DFAC
             ENDIF
-            IF (IFIXB.EQ.0) THEN
+            IF (IFIXB.NE.1) THEN
               VMIN = VMIMI
               VMAX = VMAMA
             ENDIF
@@ -861,7 +948,7 @@ Cfj     &           .AND.NOM_ISO(1:2).EQ.'$'//NOM_FICH(1:1)) CALL MYISO
               GOTO 3532
             ENDIF
             IF ((IVAL.NE.1.AND.IVAL.NE.4).OR.IMULFI.EQ.2) THEN
-              IF (IMULFI.EQ.2) IVAVA=0
+              IF (IMULFI.EQ.2) IVAVA = 0
               CALL LIVIT(ICLAS,IVAVA,CBIDON,LBID,IRC,0,1)
               IF (ISO.NE.0.AND.ISOBID.NE.ISOBID0.AND.ISOBID0.NE.0) THEN
                 ISOBID = ISOBID0
@@ -876,6 +963,15 @@ Cfj     &           .AND.NOM_ISO(1:2).EQ.'$'//NOM_FICH(1:1)) CALL MYISO
                   ENDIF
                 ENDIF
               ENDIF
+              if (imulfi.eq.2.and.facfacex.ne.1.) then
+                DFACX = FACEXAloc*(facfacex-1.)
+                DFACY = FACEXAloc*(facfacex-1.)
+                DFACZ = FACEXAloc*(facfacex-1.)
+                FACEXAloc = FACEXAloc*facfacex
+                CALL EXAGERE(DFACX,DFACY,DFACZ,IOPTEXA)
+                CALL PROJET(NBON,XMIN,XMAX,YMIN,YMAX)
+                CALL RANGEMENT(NBON)
+              endif
             ELSE
               CALL LIISO(ICLAS,CBIDON,LBID,IRC,ICONTR,IDEPL,IVAL)
               IF (I2D.NE.0.AND.FACEXA0.NE.0..AND.IREP.EQ.0) THEN
@@ -917,7 +1013,7 @@ Cfj     &           .AND.NOM_ISO(1:2).EQ.'$'//NOM_FICH(1:1)) CALL MYISO
               CALL LIISO(ICLAS,CBIDON,LBID,IRC,ICONTR,IDEPL,IVAL)
               IF (IRC.NE.0) GOTO 3532
             ENDIF
-            IF (IFIXB.EQ.0) THEN
+            IF (IFIXB.NE.1) THEN
               VMIN = VMIMI
               VMAX = VMAMA
             ELSEIF(ISO.NE.0.AND.IFORMAT.GE.0) THEN
@@ -926,7 +1022,22 @@ Cfj     &           .AND.NOM_ISO(1:2).EQ.'$'//NOM_FICH(1:1)) CALL MYISO
      &             ,VMIN,VMAX
             ENDIF
             IF (ISUSU.NE.0) THEN
-              CALL CALSUR(0)
+              IF (NRECON.GT.1) THEN
+                NRECON0 = NRECON
+                NFACE0 = NFACE
+                NRECON = 1
+                NFACE = NF
+                CALL SYMETRISE(NRECON0,0)
+                IF (NSURF.GT.0) CALL CALSUR(1)
+                NRECON = NRECON0
+                NFACE = NFACE0
+                NRECON0 = 1
+                CALL SYMETRISE(NRECON0,0)
+                IF (NSURF.GT.0.AND.ICTFAC.GT.15.AND.ICTFAC.LE.97)
+     &               CALL ELISO(IRC)
+              ELSE
+                CALL CALSUR(0)
+              ENDIF
               CALL PROJET(NBON,XMIN,XMAX,YMIN,YMAX)
               IF (NSURF.GT.0) THEN
                 CALL PROSUR(NBON)
@@ -1071,7 +1182,7 @@ C
  3532     CONTINUE
         ENDDO
       ENDDO
- 3637 IF (IFIXB.NE.0.AND.ISO.NE.0.AND.NBIMA.GT.1.AND.IFORMAT.GE.0)
+ 3637 IF (IFIXB.EQ.1.AND.ISO.NE.0.AND.NBIMA.GT.1.AND.IFORMAT.GE.0)
      &     CLOSE(IFICHB)
       CALL x11videqueue
       IF (IPROGRE0.GT.0) IPROGRE = -IPROGRE
@@ -1265,7 +1376,7 @@ C
       END
 C-----------------------------------------------------------------------
       SUBROUTINE ECCNUM(I,NBIMA,CNUM,LC)
-      CHARACTER*7 CNUM
+      CHARACTER*8 CNUM
 C
       IF (NBIMA.LT.10) THEN
         WRITE(CNUM(1:1),'(I1)') I
@@ -1282,11 +1393,14 @@ C
       ELSEIF(NBIMA.LT.100000) THEN
         WRITE(CNUM(1:5),'(I5.5)') I
         LC = 5
-      ELSEIF(NBIMA.LT.100000) THEN
+      ELSEIF(NBIMA.LT.1000000) THEN
         WRITE(CNUM(1:6),'(I6.6)') I
         LC = 6
-      ELSE
+      ELSEIF(NBIMA.LT.10000000) THEN
         WRITE(CNUM(1:7),'(I7.7)') I
         LC = 7
+      ELSE
+        WRITE(CNUM(1:8),'(I8.8)') I
+        LC = 8
       ENDIF
       END
