@@ -103,8 +103,14 @@ C
             NN = (N-1)*NDS+1
             CALL QUALITY(NODEL(NN),N,NDS)
           ENDDO
-        ELSE
+        ELSEIF(ICOURXYZ.EQ.1) THEN
           NDS = 2
+        ELSEIF(ICOURXYZ.EQ.2) THEN
+C
+C trait dans elimin3
+C
+          ICPT = NF
+          GOTO 9999
         ENDIF
         NDSEL = NDS
       ELSE
@@ -200,7 +206,7 @@ C
               NONO(KK) = NODE(IP827(KK,K))
             ENDDO
             CALL TETRA(NONO)
-          ENDDO 
+          ENDDO
         ENDDO
 C
 C 4 noeuds....
@@ -644,13 +650,13 @@ cc            NE = IBID(1)
             ENDIF
           ENDDO
           NUMNP2 = NUMNP2+1
-          X(NUMNP2) = 
+          X(NUMNP2) =
      &      .125*( X(NODE(1))+X(NODE(2))+X(NODE(3))+X(NODE(4))
      &           + X(NODE(5))+X(NODE(6))+X(NODE(7))+X(NODE(8)) )
-          Y(NUMNP2) = 
+          Y(NUMNP2) =
      &      .125*( Y(NODE(1))+Y(NODE(2))+Y(NODE(3))+Y(NODE(4))
      &           + Y(NODE(5))+Y(NODE(6))+Y(NODE(7))+Y(NODE(8)) )
-          Z(NUMNP2) = 
+          Z(NUMNP2) =
      &      .125*( Z(NODE(1))+Z(NODE(2))+Z(NODE(3))+Z(NODE(4))
      &           + Z(NODE(5))+Z(NODE(6))+Z(NODE(7))+Z(NODE(8)) )
           DEPX(NUMNP2) = .125*( DEPX(NODE(1))+DEPX(NODE(2))
@@ -777,7 +783,12 @@ C
       ELSE
         NDSB = 4
       ENDIF
-      IF (INOPO.NE.0) CALL EXEC('/bin/rm -f '//NOM_FICH(1:LONG)//'*')
+      IF (INOPO.NE.0) THEN
+        IF (ISAUVEMESH.EQ.1) THEN
+          CALL EXEC('/bin/mv -vi '//NOM_FICH(1:LONG)//'* .')
+        ENDIF
+        CALL EXEC('/bin/rm -f '//NOM_FICH(1:LONG)//'*')
+      ENDIF
       NFACE = 0
       DO 30 N=1,ICPT
         IF (ICLAS(1,N).NE.0) THEN
@@ -786,7 +797,7 @@ C
           ISD3(NFACE) = ISD3(N)
           NUMSD = MAX(NUMSD,ISD2(NFACE))
           NNUMFA(NFACE) = ICLAS(5,N)
-          NRFAC(NFACE)  = ICLAS(6,N) 
+          NRFAC(NFACE)  = ICLAS(6,N)
           DO I=1,NDSB
             NFAC(I,NFACE) = ICLAS(I,N)
             XF(I,NFACE) = X(ICLAS(I,N))
@@ -876,7 +887,8 @@ C Pourquoi c'etait commente ? 6/98
 C
       IF (I2D.NE.0) NDS = NDSB
 C
-      IF (NDS.EQ.3.OR.NDS.EQ.2) IPREFC=-1
+      IF (NDS.EQ.3.OR.NDS.EQ.2) IPREFC = -1
+      IF (IPREFC.NE.-1) IORIENT = 1
       IF (NDS.EQ.2) IFC = 1
       IF (ISTDOUT.EQ.0) THEN
         IF (ILANG.EQ.0) THEN
@@ -904,7 +916,7 @@ C
           IELBOR(NNUMFA(I)) = I
         ELSE
           IELBOR(NNUMFA(I)) = -I
-        ENDIF        
+        ENDIF
       ENDDO
       NNN = 0
       DO I=1,NEL
@@ -922,7 +934,7 @@ C
         ENDIF
       ENDIF
 C
-C Ecriture du fichier .facext 
+C Ecriture du fichier .facext
 C (8 noeuds et 4 noeuds tetra seulement pour l'instant)
 C
       IF (IFACEXT.EQ.-1.AND.IELIMI.EQ.0) THEN
