@@ -66,7 +66,7 @@ C
         YY = Y1-2.*DY
       ENDIF
       CALL ASFCOL(ICOLAXB)
-      CALL GSCHAR(XX,YY,18,MEMO)
+      CALL GSCHAR(XX,YY,17,MEMO)
       YY = YY-DY2
       IF ( NOM_FICH(1:5).EQ.'/tmp/'
      &.AND.NOM_FICH(LONG:LONG).EQ.'D'.AND.INOPO.NE.0) THEN
@@ -136,34 +136,56 @@ C
       YY = YY-DY2
       CALL GSCHAR(XX,YY,LELEM,ELEMENTS)
       YY = YY-DY2
-      WRITE (CNUM,'(I7)') NUMNP
-      IF (ILANG.EQ.0) THEN
-        CALL GSCHAR(XX,YY,16,'noeuds  :'//CNUM)
+      MAMA = MAX(NUMNP,NEL)
+      IF (MAMA.LT.100000) THEN
+        IFO = 6
       ELSE
-        CALL GSCHAR(XX,YY,16,'nodes   :'//CNUM)
+        IFO = 7
+      ENDIF
+      IF (IFO.EQ.6) THEN
+        WRITE(CNUM,'(I6,1X)') NUMNP
+      ELSE
+        WRITE(CNUM,'(I7)') NUMNP
+      ENDIF
+      IF (ILANG.EQ.0) THEN
+        CALL GSCHAR(XX,YY,14,'noeuds:'//CNUM)
+      ELSE
+        CALL GSCHAR(XX,YY,14,'nodes :'//CNUM)
       ENDIF
       IF (ICOURB.GT.0) THEN
         YY = YY-DY2
-        WRITE (CNEL,'(I7)') NEL
-        IF (ILANG.EQ.0) THEN
-          CALL GSCHAR(XX,YY,16
-     &         ,CHAR(233)//'l'//CHAR(233)//'ments:'//CNEL)
+        IF (IFO.EQ.6) THEN
+          WRITE(CNEL,'(I6,1X)') NEL
         ELSE
-          CALL GSCHAR(XX,YY,16,'elements:'//CNEL)
+          WRITE(CNEL,'(I7)') NEL
+        ENDIF
+        IF (ILANG.EQ.0) THEN
+          CALL GSCHAR(XX,YY,14
+     &         ,CHAR(233)//'l'//CHAR(233)//'mts:'//CNEL)
+        ELSE
+          CALL GSCHAR(XX,YY,14,'elemts:'//CNEL)
         ENDIF
       ENDIF
       IF (I2D.EQ.0.AND.IPS2D.EQ.0) THEN
         YY = YY-DY2
-        WRITE (CFACE,'(I7)') NFACE
-        CALL GSCHAR(XX,YY,16,'faces   :'//CFACE)
+        IF (IFO.EQ.6) THEN
+          WRITE(CFACE,'(I6,1X)') NFACE
+        ELSE
+          WRITE(CFACE,'(I7)') NFACE
+        ENDIF
+        CALL GSCHAR(XX,YY,14,'faces :'//CFACE)
       ENDIF
       IF (NUMSD.NE.1) THEN
         YY = YY-DY2
-        WRITE (CSD,'(I7)') NUMSD
-        IF (ILANG.EQ.0) THEN
-          CALL GSCHAR(XX,YY,16,'ss. dom.:'//CSD)
+        IF (IFO.EQ.6) THEN
+          WRITE(CSD,'(I6,1X)') NUMSD
         ELSE
-          CALL GSCHAR(XX,YY,16,'sub dom.:'//CSD)
+          WRITE(CSD,'(I7)') NUMSD
+        ENDIF
+        IF (ILANG.EQ.0) THEN
+          CALL GSCHAR(XX,YY,14,'ss dom:'//CSD)
+        ELSE
+          CALL GSCHAR(XX,YY,14,'subdom:'//CSD)
         ENDIF
       ENDIF
       IF (IEXAG.NE.0) THEN
@@ -570,8 +592,13 @@ c??? 4/2001                CALL ECRITVAL(X2,DX,VALFRO(I),LV00,IBID,IBID,XLEG,YY)
       IF (ISO.EQ.0.AND.ICTFAC.LT.0) THEN
         CALL GSLSS(IFONT2)
         IF (ICTFAC.EQ.-1) THEN
-          IIMIN = 1
-          IIMAX = 7
+          IF (IORIENT.LT.0) THEN
+            IIMIN = -1
+            IIMAX = 1
+          ELSE
+            IIMIN = 1
+            IIMAX = 7
+          ENDIF
         ELSEIF(ICTFAC.EQ.-2) THEN
           IIMIN = MATMIN
           IIMAX = MATMAX
@@ -582,7 +609,11 @@ c??? 4/2001                CALL ECRITVAL(X2,DX,VALFRO(I),LV00,IBID,IBID,XLEG,YY)
         CALL GSCOL(ICOLAX)
         CALL ASFCOL(ICOLAX)
         RY = YY-Y0-3.*DY
-        DDY = RY/REAL(1+IIMAX-IIMIN)
+        IF (IIMIN.GT.0) THEN
+          DDY = RY/REAL(1+IIMAX-IIMIN)
+        ELSE
+          DDY = RY/REAL(IIMAX-IIMIN)
+        ENDIF
         XXX(1) = XX+5.*DX
         XXX(2) = XXX(1)+9.*DX
         XXX(3) = XXX(2)
@@ -595,19 +626,29 @@ c??? 4/2001                CALL ECRITVAL(X2,DX,VALFRO(I),LV00,IBID,IBID,XLEG,YY)
           XXB = .6*XXX(1)+.4*XXX(2)
         ENDIF
         DO I=IIMIN,IIMAX
-          YYY(1) = YYY(4)
-          YYY(2) = YYY(3)
-          YYY(3) = YYY(3)+DDY
-          YYY(4) = YYY(4)+DDY
-          YYB = .55*YYY(1)+.45*YYY(3)
-          CALL GSPAT(ICREF(I))
-          CALL MY_GSAREA(1,XXX,YYY,4)
-          IF (IIMAX.LT.10) THEN
-            WRITE (CCC(1:1),'(I1)') I
-            CALL GSCHAR2(XXB,YYB,1,CCC(1:1))
-          ELSE
-            WRITE (CCC(1:2),'(I2)') I
-            CALL GSCHAR2(XXB,YYB,2,CCC(1:2))
+          IF (I.NE.0) THEN
+            YYY(1) = YYY(4)
+            YYY(2) = YYY(3)
+            YYY(3) = YYY(3)+DDY
+            YYY(4) = YYY(4)+DDY
+            YYB = .55*YYY(1)+.45*YYY(3)
+            IF (IIMIN.LT.0) THEN
+              IF (I.LT.0) THEN
+                CALL GSPAT(9)
+              ELSE
+                CALL GSPAT(4)
+              ENDIF
+            ELSE
+              CALL GSPAT(ICREF(MOD(I,16)))
+            ENDIF
+            CALL MY_GSAREA(1,XXX,YYY,4)
+            IF (IIMAX.LT.10.AND.IIMIN.GT.0) THEN
+              WRITE(CCC(1:1),'(I1)') I
+              CALL GSCHAR2(XXB,YYB,1,CCC(1:1))
+            ELSE
+              WRITE(CCC(1:2),'(I2)') I
+              CALL GSCHAR2(XXB,YYB,2,CCC(1:2))
+            ENDIF
           ENDIF
         ENDDO
         CALL GSLSS(IFONT1)
@@ -677,8 +718,12 @@ C
      &         //'affiche la prsente liste des options.'
           PRINT*,' -v,-V,--version : '
      &         //'affiche la version et la mmoire utilise'
+          PRINT*,' '
           PRINT*,' -english     : English version'
           PRINT*,' -french      : Version franaise'
+          PRINT*,
+     &         ' -arrow[=fact]: affiche les flches en '
+     &         //'prsence de fichier vectoriel'
           PRINT*,' -axis=n      : axes ou non:'
           PRINT*,'   0: rien (dfaut 2d)'
           PRINT*,'   1: en haut  gauche'
@@ -759,8 +804,18 @@ C     &' -fullshrink  : idem + shrink proportionnel  champ scalaire'
           PRINT*,'   2: frontires rfrences'
           PRINT*,'   3: frontires rfrences + blocages'
           PRINT*,'   4: frontires de sous-domaines (si plusieurs SD)'
+          PRINT*,
+     & ' -gouraud=n : lissage Gouraud pour les isosurfaces'
+          PRINT*,'   1: lumire diffuse'
+          PRINT*,'   2: lumire ponctuelle'
           PRINT*,' -[no]hidden  : trac avec faces caches ou non.'
           PRINT*,'(dfauts: 2d nohidden, 3d hidden)'
+          PRINT*,
+     &' -info=n : affichage des boutons et des informations diverses'
+          PRINT*,'   0: tout (dfaut)'
+          PRINT*,'   1: pas de boutons  gauche'
+          PRINT*,
+     &'   2: pas de boutons  gauche ni d''informations  droite'
           PRINT*,' -iso=c (c=x,y,z) : '//
      &         'isovaleurs calcules avec l''une des coordonnes'
           PRINT*,
@@ -857,6 +912,10 @@ c     &'        "-psdef=nosign,port" (info ou noinfo selon les besoins)'
      &' -roty=angle  : position angulaire initiale autour de Oy.'
           PRINT*,
      &' -rotz=angle  : position angulaire initiale autour de Oz.'
+          PRINT*,
+     &' -savemesh    : sauvegarde automatique du .avoirND lorsque le'
+          PRINT*,
+     &'                maillage de dpart est dans un autre format.'
           PRINT*,' -sym=[n]     : symtries (n=1,2,3,4 ou plus).'
           PRINT*,'                pas d''argument -> symtrie max'
           PRINT*,' -symr        : symtries de rotation et non axiales'
@@ -871,7 +930,7 @@ c     &'        "-psdef=nosign,port" (info ou noinfo selon les besoins)'
           PRINT*,
      &' -vmin=valeur : borne infrieure de la table des isovaleurs.'
           PRINT*,' -xcentr=X    : coordonne X du centre du cadrage'
-          PRINT*,' -xcentr=Y    : coordonne Y du centre du cadrage'
+          PRINT*,' -ycentr=Y    : coordonne Y du centre du cadrage'
           PRINT*,' -zoom=facteur: facteur de zoom'
           PRINT*,' '
           PRINT*,
@@ -886,8 +945,11 @@ C-----------
      &         //'displays the present list.'
           PRINT*,' -v,-V,--version: '
      &         //'displays the version and the available memory.'
+          PRINT*,' '
           PRINT*,' -english     : English version'
           PRINT*,' -french      : Version franaise'
+          PRINT*,
+     &' -arrow[=fact]: displays arrows if a vector field is given.'
           PRINT*,' -axis=n      : axis definition'
           PRINT*,'   0: no axis (default 2d)'
           PRINT*,'   1: upper left corner'
@@ -967,8 +1029,18 @@ C     &' -fullshrink  : idem + shrink proportionnal a scalar field.'
           PRINT*,'   2: referenced boundaries'
           PRINT*,'   3: referenced boundaries + clamping conditions'
           PRINT*,'   4: subdomain boundaries (if several SD)'
+          PRINT*,
+     & ' -gouraud=n : Gouraud smoothing of isocontours'
+          PRINT*,'   1: diffuse light'
+          PRINT*,'   2: ponctual light'
           PRINT*,' -[no]hidden  : hidden facets or not.'
           PRINT*,'(defaults: 2d nohidden, 3d hidden)'
+          PRINT*,
+     &' -info=n : display menus and informations about the plot'
+          PRINT*,'   0: displays everything (dfaut)'
+          PRINT*,'   1: no menus (left zone)'
+          PRINT*,
+     &'   2: no menus and no informations zone (on the right)'
           PRINT*,' -iso=c (c=x,y,z) : '//
      &           'isocontour using one of the coordinates'
           PRINT*,
@@ -1065,6 +1137,10 @@ cc     &'        "-psdef=nosign,port" (info or noinfo according to needs)'
      &' -roty=angle  : initial angular position about Oy.'
           PRINT*,
      &' -rotz=angle  : initial angular position about Oz.'
+          PRINT*,
+     &' -savemesh    : save automatically the mesh in avoirND format if'
+          PRINT*,
+     &'                the initial mesh is in another known format.'
           PRINT*,' -sym[=n]     : symmetries (n=1,2,3,4 or more).'
           PRINT*,'                no argument -> maximal symmetry'
           PRINT*,' -symr        : central symmetries instead of axial'
@@ -1079,13 +1155,13 @@ cc     &'        "-psdef=nosign,port" (info or noinfo according to needs)'
           PRINT*,
      &' -vmin=value  : lower bound for the color table.'
           PRINT*,' -xcentr=X    : X coordinate of the crop center'
-          PRINT*,' -xcentr=Y    : Y coordinate of the crop center'
+          PRINT*,' -ycentr=Y    : Y coordinate of the crop center'
           PRINT*,' -zoom=facteur: zoom cofficient'
           PRINT*,' '
           PRINT*,'For bug report and suggestions, a single address:'
         ENDIF
         PRINT*,' '
-        PRINT*,'         Francois.Jouve@polytechnique.fr'
+        PRINT*,'         francois.jouve@polytechnique.fr'
         PRINT*,' '
         STOP
       ENDIF
