@@ -707,7 +707,7 @@ C 38
      &       'fichier de maillage (en bascule)'
       ELSE
         CBOUT(IB) = 'title'
-        HBOUT(IB) = '_ : displys the title of the mesh file (toggle)'
+        HBOUT(IB) = '_ : displays the title of the mesh file (toggle)'
       ENDIF
       IF (ICOURB.GT.0) THEN
         LBOUT(IB) = 5
