@@ -65,12 +65,13 @@ c      ICTFLE  = 15
       IINFO   = 1
       IMAILL  = 1
       INUMER  = 0
-      ISHRINK = 1
+      IORIENT = -1
       IPCOUP  = 0
       IPOST   = 1
       IPREFC  = 1
       IPS2D   = 0
       ISHPRO  = 1
+      ISHRINK = 1
       IF (IPARA.GE.0) THEN
         ISO = 0
       ELSE
@@ -114,7 +115,7 @@ c      ICTFLE  = 15
         IPERSP  = -2
         DATE = KINFO('DATE')
         MOI  = KINFO('UTILISATEUR')
-        MEMO = DATE(5:6)//'/'//DATE(3:4)//'/'//DATE(1:2)//'  '//MOI
+        MEMO = DATE(5:6)//'/'//DATE(3:4)//'/'//DATE(1:2)//' '//MOI
       ELSE
         DO J=1,3
           DO I=1,3
@@ -540,7 +541,7 @@ C
           WRITE(*,'(A,$)') 'Translation of the '
      &         //SUF(ISUF)(1:LSU)//' file...'
         ENDIF
-        CALL FREEFEM2AVOIR(NOM_FICH,LONG,INOPO,LSU,ILANG)
+        CALL FREEFEM2AVOIR(NOM_FICH,LONG,INOPO,LSU,ILANG,NTET)
         IF (ISTDOUT.EQ.0) PRINT*,'OK --> '//NOM_FICH(1:LONG)
         IPREM = 1
         GOTO 2
@@ -548,12 +549,33 @@ C
 C
       END
 C-----------------------------------------------------------------------
-      SUBROUTINE FREEFEM2AVOIR(NOM_FICH,LONG,INOPO,LSU,ILANG)
+      SUBROUTINE FREEFEM2AVOIR(NOM_FICH,LONG,INOPO,LSU,ILANG,ITMP)
       CHARACTER*128 NOM_FICH
       CHARACTER*11  BID
       INCLUDE '../include/com_avoir.f'
-      INTEGER NTITI(15)
-      DATA NTITI / 2,3,4,4,8,6,5,3,6,9,10,27,18,14,1 /
+      INTEGER ITMP(0:27,*)
+      INTEGER NTITI(19),IBID1(20),NSDEFF(NGMAX)
+      DATA NTITI / 2,3,4,4,8,6,5,3,6,9,10,27,18,14,1,8,20,15,13 /
+C Types d'elements de Gmsh
+C  1   2-node line.
+C  2   3-node triangle.
+C  3   4-node quadrangle.
+C  4   4-node tetrahedron.
+C  5   8-node hexahedron.
+C  6   6-node prism.
+C  7   5-node pyramid.
+C  8   3-node second order line (2 nodes associated with the vertices and 1 with the edge).
+C  9   6-node second order triangle (3 nodes associated with the vertices and 3 with the edges).
+C 10   9-node second order quadrangle (4 nodes associated with the vertices, 4 with the edges and 1 with the face).
+C 11   10-node second order tetrahedron (4 nodes associated with the vertices and 6 with the edges).
+C 12   27-node second order hexahedron (8 nodes associated with the vertices, 12 with the edges, 6 with the faces and 1 with the volume).
+C 13   18-node second order prism (6 nodes associated with the vertices, 9 with the edges and 3 with the quadrangular faces).
+C 14   14-node second order pyramid (5 nodes associated with the vertices, 8 with the edges and 1 with the quadrangular face).
+C 15   1-node point.
+C 16   8-node second order quadrangle (4 nodes associated with the vertices and 4 with the edges).
+C 17   20-node second order hexahedron (8 nodes associated with the vertices and 12 with the edges).
+C 18   15-node second order prism (6 nodes associated with the vertices and 9 with the edges).
+C 19   13-node second order pyramid (5 nodes associated with the vertices and 8 with the edges).
 C
       NUMSD = 1
       NGROUP(1) = 1
@@ -627,7 +649,7 @@ C
             ENDIF
             STOP
           ENDIF
-            PRINT*,' '
+          PRINT*,' '
           IF (ILANG.EQ.0) THEN
             PRINT*,'Maillage venant de Gmsh. msh format version',VERS
           ELSE
@@ -648,30 +670,112 @@ C
           READ(1,'(A)') BID(1:1)
           READ(1,*) NNN
           NDSM = 0
+          NUMSD = 0
+          NUMSDEFF = 0
           IF (VERS.EQ.1.) THEN
             DO I=1,NNN
-              READ(1,*) IBID,(IBID1,K=1,3)
-     &                 ,NPR(I),(NODE(K,I),K=1,NPR(I))
+              READ(1,*) IBID,(IBID1(K),K=1,3)
+     &                 ,NPR(I),(ITMP(K,I),K=1,NPR(I))
               NDSM = MAX(NDSM,NPR(I))
+              IF (NUMSDEFF.EQ.0) THEN
+                NUMSDEFF = 1
+                NSDEFF(1) = IBID1(2)
+              ELSE
+                IMAT = 0
+                DO K=1,NUMSDEFF
+                  IF (NSDEFF(K).EQ.IBID1(2)) IMAT = K
+                ENDDO
+                IF (IMAT.EQ.0) THEN
+                  NUMSDEFF = NUMSDEFF+1
+                  NSDEFF(NUMSDEFF) = IBID1(2)
+                  IMAT = NUMSDEFF
+                ENDIF
+              ENDIF
+              ITMP(0,I) = IBID1(2)
             ENDDO
           ELSE
             DO I=1,NNN
-              READ(1,*) IBID,ITYP,NTAG,(IBID2,K=1,NTAG)
-     &                 ,(NODE(K,I),K=1,NTITI(ITYP))
+              READ(1,*) IBID,ITYP,NTAG,(IBID1(K),K=1,NTAG)
+     &                 ,(ITMP(K,I),K=1,NTITI(ITYP))
               NPR(I) = NTITI(ITYP)
               NDSM = MAX(NDSM,NPR(I))
+              IF (NUMSDEFF.EQ.0) THEN
+                NUMSDEFF = 1
+                NSDEFF(1) = IBID1(2)
+              ELSE
+                IMAT = 0
+                DO K=1,NUMSDEFF
+                  IF (NSDEFF(K).EQ.IBID1(2)) IMAT = K
+                ENDDO
+                IF (IMAT.EQ.0) THEN
+                  NUMSDEFF = NUMSDEFF+1
+                  NSDEFF(NUMSDEFF) = IBID1(2)
+                  IMAT = NUMSDEFF
+                ENDIF
+              ENDIF
+              ITMP(0,I) = IBID1(2)
             ENDDO
           ENDIF
-          NEL(1) = 0
-          NDS(1) = NDSM
+C
+C Visiblement Gmsh met toutes les primitives comme des lments.
+C Exemple : pour faire un maillage 2d, on cree des lignes, puis le
+C maillage 2d. Gmsh met dans le fichier d'abord une liste de segments,
+C puis les lments 2d. Idem pour le 3d :
+C il conserve les elements 1d et 2d.
+C Pour xd3d il faut filtrer tout a et c'est un peu galre... (2/07)
+C Il y a aussi les sous-domaines.
+C Pour l'instant on fait simple : on suppose que tous les elements
+C ont le mme nombre de noeuds = NDSM (ou bien on bidouille pour mixer
+C les triangles et quadrangles en 2d).
+C
+          DO I=1,NGMAX
+            NEL(I) = 0
+            NDS(I) = NDSM
+          ENDDO
           DO I=1,NNN
-            IF (NPR(I).EQ.NDSM) THEN
-              NEL(1) = NEL(1)+1
-              DO K=1,NDSM
-                NODE(K,NEL(1)) = IBC(1,NODE(K,I))
+            IF (NPR(I).EQ.NDSM
+     &.OR.(NDSM.EQ.4.AND.NPR(I).EQ.3.AND.NDIDI.EQ.2)) THEN
+              IMAT = 0
+              DO K=1,NUMSDEFF
+                IF (NSDEFF(K).EQ.ITMP(0,I)) IMAT = K
+              ENDDO
+              IF (IMAT.EQ.0) THEN
+                DO K=1,NUMSDEFF
+                  PRINT*,K,NSDEFF(K)
+                ENDDO
+                PRINT*,
+     &               '*** BUG in the GMSH format convertion',I,ITMP(0,I)
+                STOP
+              ENDIF
+              NSD = IMAT
+              NEL(NSD) = NEL(NSD)+1
+              NUMSD = MAX(NUMSD,NSD)
+              IF (NDSM.EQ.4.AND.NPR(I).EQ.3) THEN
+                NPR(I) = 4
+                ITMP(4,I) = ITMP(3,I)
+              ENDIF
+            ENDIF
+          ENDDO
+          NUMSD2 = NUMSD
+          NUMSD = 0
+          NN = 0
+          DO N=1,NUMSD2
+            IF (NEL(N).GT.0) THEN
+              PRINT*,'Group',N,NEL(N)
+              NUMSD = NUMSD+1
+              NGROUP(NUMSD) = NUMSD
+              NEL(NUMSD) = NEL(N)
+              DO I=1,NNN
+                NODE(0,NN) = numsd
+c                NODE(0,NN) = ITMP(0,I)
+                IF (NPR(I).EQ.NDSM.AND.ITMP(0,I).EQ.nsdeff(N)) THEN
+                  NN = NN+1
+                  DO K=1,NDSM
+                    NODE(K,NN) = IBC(1,ITMP(K,I))
+                  ENDDO
+                ENDIF
               ENDDO
             ENDIF
-            NPR(I) = 0
           ENDDO
           DO I=1,IBIDMAX
             IBC(1,I) = 0
