@@ -52,6 +52,7 @@ C
             HED(I:I) = CWORK(I)
           ENDDO
         ENDIF
+        CALL FILTRE_BAD_CHAR(HED,80)
         CALL ENLEVE_TOUS_BLANCS(HED,LONTIT,80)
         IF (LONTIT.NE.0.AND.ISTDOUT.EQ.0) WRITE(*,1000) HED(1:LONTIT)
         IF (IARCH.EQ.0) THEN
@@ -874,7 +875,7 @@ C
           ELSE
             WRITE(CEXP(1:6),'(2H +,I3,1H )') NBCOM
           ENDIF
-          print*,
+          PRINT*,
      &         'tail'//CEXP(1:6)//NOM_FICH(1:LONG)//'> /tmp/bidonbidon'
           CALL EXEC(
      &         'tail'//CEXP(1:6)//NOM_FICH(1:LONG)//'> /tmp/bidonbidon')
@@ -966,11 +967,26 @@ C Raw pgm
       ELSEIF(ICOURB.EQ.-5) THEN
 C
 C Fichier de points xyz (generation d'un maillage Delaunay -> nappe)
-C ou bien courbe (1d) dans l'espace si fichier commence par #+
+C ou bien courbe (1d) dans l'espace si le fichier commence par #+
+C ou bien succession de //llpipdes si le fichier commence par #<
 C
  3333   READ(IFAC,'(A2)') HED(1:2)
         IF (HED(1:1).EQ.'#') THEN
           IF (HED(2:2).EQ.'+') ICOURXYZ = 1
+          IF (HED(2:2).EQ.'<') THEN
+            ICOURXYZ = 2
+            BACKSPACE(IFAC)
+            READ(IFAC,'(A80)') HED
+            CALL ENLEVE_TOUS_BLANCS(HED(3:80),L,78)
+            IF (L.GT.0) THEN
+              READ(HED(3:L+2),*) DCUBEX,DCUBEY,DCUBEZ
+              print*,DCUBEX,DCUBEY,DCUBEZ
+            ELSE
+              DCUBEX = 0.
+              DCUBEY = 0.
+              DCUBEZ = 0.
+            ENDIF
+          ENDIF
           GOTO 3333
         ELSE
           BACKSPACE(IFAC)
@@ -982,23 +998,116 @@ C
         YMAX = -BIG
         ZMIN = BIG
         ZMAX = -BIG
-        NPMAX2 = MIN(1+NFMAX/2,NPMAX)
-        DO I=1,NPMAX2
-          READ(IFAC,*,END=3334,ERR=3334) X(I),Y(I),Z(I)
-          NUMNP = NUMNP+1
-          XMIN = MIN(XMIN,X(I))
-          XMAX = MAX(XMAX,X(I))
-          YMIN = MIN(YMIN,Y(I))
-          YMAX = MAX(YMAX,Y(I))
-          ZMIN = MIN(ZMIN,Z(I))
-          ZMAX = MAX(ZMAX,Z(I))
-          IREF(I)  = 0
-          IREF3(I) = 0
-          IBLOQ(I) = 0
-          DEPX(I) = X(I)
-          DEPY(I) = Y(I)
-          DEPZ(I) = Z(I)
-        ENDDO
+        IF (ICOURXYZ.EQ.2) THEN
+          NPMAX2 = MIN(NFMAX/6,NPMAX/8)
+          I = 1
+          DO J=1,NPMAX2
+            READ(IFAC,*,END=3335,ERR=3335) X(I),Y(I),Z(I)
+            XMIN = MIN(XMIN,X(I))
+            XMAX = MAX(XMAX,X(I))
+            YMIN = MIN(YMIN,Y(I))
+            YMAX = MAX(YMAX,Y(I))
+            ZMIN = MIN(ZMIN,Z(I))
+            ZMAX = MAX(ZMAX,Z(I))
+            IREF(I)  = 0
+            IREF3(I) = 0
+            IBLOQ(I) = 0
+            DEPX(I) = X(I)
+            DEPY(I) = Y(I)
+            DEPZ(I) = Z(I)
+            NUMNP = NUMNP+1
+            I = I+8
+          ENDDO
+ 3335     IF (DCUBEX.LE.0.) THEN
+            NX = MAX(NINT(REAL(NUMNP)**(0.3333)),3)
+            DCUBEX = (XMAX-XMIN)/REAL(NX)
+            DCUBEY = (YMAX-YMIN)/REAL(NX)
+            DCUBEZ = (ZMAX-ZMIN)/REAL(NX)
+          ENDIF
+          DCUBEX2 = 0.5*DCUBEX
+          DCUBEY2 = 0.5*DCUBEY
+          DCUBEZ2 = 0.5*DCUBEZ
+          DO I=1,NUMNP
+            J = 8*I-7
+            X(J) = X(J)-DCUBEX2
+            Y(J) = Y(J)-DCUBEY2
+            Z(J) = Z(J)-DCUBEZ2
+C
+            X(J+1) = X(J)+DCUBEX
+            X(J+2) = X(J)+DCUBEX
+            X(J+3) = X(J)
+            X(J+4) = X(J)
+            X(J+5) = X(J+1)
+            X(J+6) = X(J+2)
+            X(J+7) = X(J+3)
+C
+            Y(J+1) = Y(J)
+            Y(J+2) = Y(J)+DCUBEY
+            Y(J+3) = Y(J)+DCUBEY
+            Y(J+4) = Y(J)
+            Y(J+5) = Y(J+1)
+            Y(J+6) = Y(J+2)
+            Y(J+7) = Y(J+3)
+C
+            Z(J+1) = Z(J)
+            Z(J+2) = Z(J)
+            Z(J+3) = Z(J)
+            Z(J+4) = Z(J)+DCUBEZ
+            Z(J+5) = Z(J)+DCUBEZ
+            Z(J+6) = Z(J)+DCUBEZ
+            Z(J+7) = Z(J)+DCUBEZ
+C
+            DEPX(J) = -DCUBEX2
+            DEPY(J) = -DCUBEY2
+            DEPZ(J) = -DCUBEZ2
+            DEPX(J+1) = DCUBEX2
+            DEPY(J+1) = -DCUBEY2
+            DEPZ(J+1) = -DCUBEZ2
+            DEPX(J+2) = DCUBEX2
+            DEPY(J+2) = DCUBEY2
+            DEPZ(J+2) = -DCUBEZ2
+            DEPX(J+3) = -DCUBEX2
+            DEPY(J+2) = DCUBEY2
+            DEPZ(J+2) = -DCUBEZ2
+            DEPX(J+4) = -DCUBEX2
+            DEPY(J+4) = -DCUBEY2
+            DEPZ(J+4) = DCUBEZ2
+            DEPX(J+5) = DCUBEX2
+            DEPY(J+5) = -DCUBEY2
+            DEPZ(J+5) = DCUBEZ2
+            DEPX(J+6) = DCUBEX2
+            DEPY(J+6) = DCUBEY2
+            DEPZ(J+6) = DCUBEZ2
+            DEPX(J+7) = -DCUBEX2
+            DEPY(J+7) = DCUBEY2
+            DEPZ(J+7) = DCUBEZ2
+          ENDDO
+          XMIN = XMIN-DCUBEX2
+          XMAX = XMAX+DCUBEX2
+          YMIN = YMIN-DCUBEY2
+          YMAX = YMAX+DCUBEZ2
+          ZMIN = ZMIN-DCUBEZ2
+          ZMAX = ZMAX+DCUBEZ2
+        ELSE
+          NPMAX2 = MIN(NFMAX/2,NPMAX)
+cc? 7/07          NPMAX2 = MIN(1+NFMAX/2,NPMAX)
+          DO I=1,NPMAX2
+            READ(IFAC,*,END=3334,ERR=3334) X(I),Y(I),Z(I)
+            XMIN = MIN(XMIN,X(I))
+            XMAX = MAX(XMAX,X(I))
+            YMIN = MIN(YMIN,Y(I))
+            YMAX = MAX(YMAX,Y(I))
+            ZMIN = MIN(ZMIN,Z(I))
+            ZMAX = MAX(ZMAX,Z(I))
+            IREF(I)  = 0
+            IREF3(I) = 0
+            IBLOQ(I) = 0
+            DEPX(I) = X(I)
+            DEPY(I) = Y(I)
+            DEPZ(I) = Z(I)
+            NUMNP = NUMNP+1
+          ENDDO
+        ENDIF
  3334   XMIN0 = 0.
         XMAX0 = 0.
         YMIN0 = 0.
@@ -1013,6 +1122,7 @@ C
             PRINT*,NUMNP,' points red'
           ENDIF
         ENDIF
+        IF (ICOURXYZ.EQ.2) NUMNP = NUMNP*8
         IF (NUMNP.EQ.NPMAX2) THEN
           IF (ISTDOUT.EQ.0) THEN
             IF (ILANG.EQ.0) THEN
@@ -1036,7 +1146,11 @@ C
             XMIN = LOG10(XMIN)
             XMAX = LOG10(XMAX)
           ELSE
-            PRINT*,'*** Echelle Log en x impossible'
+            IF (ILANG.EQ.0) THEN
+              PRINT*,'*** Echelle Logarithmique en x impossible'
+            ELSE
+              PRINT*,'*** Logarithmic scale in x impossible'
+            ENDIF
             ILOGX = 0
           ENDIF
         ENDIF
@@ -1049,7 +1163,11 @@ C
             YMIN = LOG10(YMIN)
             YMAX = LOG10(YMAX)
           ELSE
-            PRINT*,'*** Echelle Log en y impossible'
+            IF (ILANG.EQ.0) THEN
+              PRINT*,'*** Echelle Logarithmique en y impossible'
+            ELSE
+              PRINT*,'*** Logarithmic scale in y impossible'
+            ENDIF
             ILOGY = 0
           ENDIF
         ENDIF
@@ -1062,7 +1180,11 @@ C
             ZMIN = LOG10(ZMIN)
             ZMAX = LOG10(ZMAX)
           ELSE
-            PRINT*,'*** Echelle Log en z impossible'
+            IF (ILANG.EQ.0) THEN
+              PRINT*,'*** Echelle Logarithmique en z impossible'
+            ELSE
+              PRINT*,'*** Logarithmic scale in z impossible'
+            ENDIF
             ILOGZ = 0
           ENDIF
         ENDIF
@@ -1079,7 +1201,7 @@ C
               PRINT*,NELDEL,' triangles generated in',REAL(T2-T1),' s'
             ENDIF
           ENDIF
-        ELSE
+        ELSEIF(ICOURXYZ.EQ.1) THEN
           NELDEL = NUMNP-1
           DO I=1,NELDEL
             ICLAS(1,I) = I
@@ -1090,6 +1212,12 @@ C
             ICLAS(6,I) = 0
             ICLAS(7,I) = 0
           ENDDO
+        ELSEIF(ICOURXYZ.EQ.2) THEN
+          DO I=1,NUMNP
+            IREF(I)  = 0
+            IREF3(I) = 0
+            IBLOQ(I) = 0
+          ENDDO
         ENDIF
         IF (ISTDOUT.EQ.0) THEN
           IF (ILANG.EQ.0) THEN
