@@ -6,7 +6,8 @@
      &                ,INIT_FICH2,INIT_BORD,INIT_DEFPS,INIT_NBCOUL
      &                ,INIT_FLECH,INIT_RECON,INIT_ISOBID,INIT_IBOITE
      &                ,INIT_IECBOI,INIT_FOND,INIT_IAXES,INIT_IPERSP
-     &                ,INIT_DIRL,INIT_MODE,INIT_DEPL,INIT_SYMINV)
+     &                ,INIT_DIRL,INIT_MODE,INIT_DEPL,INIT_SYMINV
+     &                ,INIT_ICTFAC)
       INCLUDE 'com_options.f'
       CHARACTER*128 FICLEC,FICLEC2,CBIDON
       INTEGER IVIRG(10)
@@ -41,6 +42,7 @@ C
       INIT_FOND   = -1
       INIT_IAXES  = -1
       INIT_IBOITE = -1
+      INIT_ICTFAC = 0
       INIT_IECBOI = -1
       INIT_IPERSP = 0
       INIT_ISO    = 0
@@ -262,6 +264,12 @@ C
                 READ(CBIDON(9:LBID),*) XINIT_FACV
                 IF (XINIT_FACV.EQ.0.) XINIT_FACV = 1.E-4
               ENDIF
+            ELSEIF(LBID.GE.6.AND.CBIDON(1:6).EQ.'-arrow') THEN
+              INIT_FLECH = 1
+              IF (LBID.GT.6.AND.CBIDON(7:7).EQ.'=') THEN
+                READ(CBIDON(8:LBID),*) XINIT_FACV
+                IF (XINIT_FACV.EQ.0.) XINIT_FACV = 1.E-4
+              ENDIF
             ELSEIF(LBID.EQ.9.AND.CBIDON(1:9).EQ.'-francais') THEN
               III = ILANG
               ILANG = 0
@@ -286,10 +294,22 @@ C
               IELIMI = 1
               IF (LBID.GE.11.AND.CBIDON(1:11).EQ.'-fullshrink')
      &          IDEBRAP = 1
+            ELSEIF(LBID.EQ.10.AND.CBIDON(1:9).EQ.'-gouraud=') THEN
+              IF (CBIDON(10:10).EQ.'1') THEN
+                INIT_ICTFAC = 97
+              ELSEIF(CBIDON(10:10).EQ.'2') THEN
+                INIT_ICTFAC = 96
+              ENDIF
             ELSEIF(LBID.GE.7.AND.CBIDON(1:7).EQ.'-hidden') THEN
               IFC = 1
             ELSEIF(LBID.GE.9.AND.CBIDON(1:9).EQ.'-nohidden') THEN
               IFC = -1
+            ELSEIF(LBID.EQ.7.AND.CBIDON(1:6).EQ.'-info=') THEN
+              IF (CBIDON(7:7).EQ.'1') THEN
+                IDEPOUILLE = 1
+              ELSEIF(CBIDON(7:7).EQ.'2') THEN
+                IDEPOUILLE = 2
+              ENDIF
             ELSEIF((LBID.EQ.6.OR.LBID.GE.7)
      &             .AND.CBIDON(1:5).EQ.'-iso=') THEN
               IF (LBID.EQ.6) THEN
@@ -389,14 +409,14 @@ C
               ELSE
                 IOPTFORME = 1
               ENDIF
-              NODEPL = 1
+cc              NODEPL = 1
             ELSEIF(LBID.GE.4.AND.CBIDON(1:4).EQ.'-lev') THEN
               IF (CBIDON(5:5).EQ.'0') THEN
                 IOPTFORME = -2
               ELSE
                 IOPTFORME = -1
               ENDIF
-              NODEPL = 1
+cc              NODEPL = 1
             ELSEIF(LBID.GT.7.AND.CBIDON(1:7).EQ.'-persp=') THEN
               READ(CBIDON(8:LBID),*) INIT_IPERSP
               IF (INIT_IPERSP.LT.0.OR.INIT_IPERSP.GT.3) THEN
@@ -489,6 +509,8 @@ Cfj                    ENDIF
               READ(CBIDON(7:LBID),*) XINIT_ROTY
             ELSEIF(LBID.GT.6.AND.CBIDON(1:6).EQ.'-rotz=') THEN
               READ(CBIDON(7:LBID),*) XINIT_ROTZ
+            ELSEIF(LBID.GE.9.AND.CBIDON(1:9).EQ.'-savemesh') THEN
+              ISAUVEMESH = 1
             ELSEIF(LBID.GE.4.AND.CBIDON(1:4).EQ.'-sym') THEN
               IF (LBID.GT.5.AND.CBIDON(1:5).EQ.'-sym=') THEN
                 READ(CBIDON(6:LBID),*) INIT_RECON
