@@ -213,7 +213,7 @@ C
           IDEROUL = 0
         ELSE
           IF (IDEROUL.LE.7) THEN
-            IF (ICTFAC.LT.96) ICTFAC=99
+            IF (ICTFAC.LT.96) ICTFAC = 99
             IDIRL = IDEROUL-2
             IF (IDIRL.EQ.-1) IDIRL = 6
           ELSE
@@ -769,6 +769,14 @@ Cfj
           LDEROUL(I) = 2
           ICOLDEROUL(I) = 0
         ENDDO
+        NDER = NDER+1
+        IF (ILANG.EQ.0) THEN
+          CDEROUL(NDER) = 'perso'
+          LDEROUL(NDER) = 5
+        ELSE
+          CDEROUL(NDER) = 'custom'
+          LDEROUL(NDER) = 6
+        ENDIF
         IDEROUL = ITABLE
         IDER0 = IDEROUL
         XBSAUV = XBOUT(2,IBOUT)
@@ -779,6 +787,8 @@ Cfj
         XBOUT(2,IBOUT) = XBSAUV
         IF (IDEROUL.LE.0.OR.IDEROUL.GT.NDER.OR.IDEROUL.EQ.IDER0) THEN
           IDEROUL = 0
+        ELSEIF(IDEROUL.EQ.NDER) THEN
+          ITABLE = ITABLE+4000
         ELSE
           ITABLE = IDEROUL-1
           IF (ITABLE.EQ.0) ITABLE = NDER
@@ -846,15 +856,24 @@ Cfj
       ELSEIF(IPFK.EQ.25) THEN
         CALL LESCOULEURS(CDEROUL,LDEROUL,ICOLDEROUL,ILANG)
         NDER = 16
-        IF (I2D.EQ.0) THEN
+        IF (I2D.EQ.0.AND.ICOURB.GT.0) THEN
           NDER = NDER+1
-          IF (ILANG.EQ.0) THEN
-            CDEROUL(NDER) = '-1: Num. faces'
-          ELSE
-            CDEROUL(NDER) = '-1: Faces num.'
-          ENDIF
-          LDEROUL(NDER) = 14
           ICOLDEROUL(NDER) = 0
+          IF (IORIENT.LT.0) THEN
+            IF (ILANG.EQ.0) THEN
+              CDEROUL(NDER) = '-1: Orientation faces '
+            ELSE
+              CDEROUL(NDER) = '-1: Facets orientation'
+            ENDIF
+            LDEROUL(NDER) = 22
+          ELSE
+            IF (ILANG.EQ.0) THEN
+              CDEROUL(NDER) = '-1: Num. faces'
+            ELSE
+              CDEROUL(NDER) = '-1: Facets num'
+            ENDIF
+            LDEROUL(NDER) = 14
+          ENDIF
         ENDIF
         IF (IFLAG3.NE.0) THEN
           NDER = NDER+1
@@ -877,6 +896,14 @@ Cfj
           ICOLDEROUL(NDER) = 0
         ENDIF
         NDER = NDER+1
+        IF (ILANG.EQ.0) THEN
+          CDEROUL(NDER) = '4X: Table personnalise'
+        ELSE
+          CDEROUL(NDER) = '4X: Custom color table '
+        ENDIF
+        LDEROUL(NDER) = 23
+        ICOLDEROUL(NDER) = 0
+        NDER = NDER+1
         IF (ILANG.EQ.0) THEN
           CDEROUL(NDER) = '99: Ombres normales'
         ELSE
@@ -922,7 +949,7 @@ Cfj
         ENDIF
         IDER0 = IDEROUL
         XBSAUV = XBOUT(1,IBOUT)
-        XBOUT(1,IBOUT) = 1.75*XBSAUV-.75*XBOUT(2,IBOUT)
+        XBOUT(1,IBOUT) = 1.75*XBSAUV - 0.75*XBOUT(2,IBOUT)
         CALL DEROULE(CTITRE,LTITRE,NTITRE,ICTITRE,IFONT8
      &              ,XBOUT(1,IBOUT),YBOUT(1,IBOUT),CDEROUL,LDEROUL
      &              ,ICOLDEROUL,NDER,IDEROUL,IMENU(IBOUT),IFONT7,0)
@@ -933,11 +960,15 @@ Cfj
           IF (IDEROUL.LE.16) THEN
             ICTFAC = IDEROUL-1
           ELSE
-            IBID = ICHAR(CDEROUL(IDEROUL)(2:2)) - 48
-            IF (CDEROUL(IDEROUL)(1:1).EQ.'-') THEN
-              ICTFAC = -IBID
+            IF (CDEROUL(IDEROUL)(1:2).EQ.'4X') THEN
+              ICTFAC = 4000 + ICTFAC
             ELSE
-              ICTFAC = IBID + 10*(ICHAR(CDEROUL(IDEROUL)(1:1)) - 48)
+              IBID = ICHAR(CDEROUL(IDEROUL)(2:2)) - 48
+              IF (CDEROUL(IDEROUL)(1:1).EQ.'-') THEN
+                ICTFAC = -IBID
+              ELSE
+                ICTFAC = IBID + 10*(ICHAR(CDEROUL(IDEROUL)(1:1)) - 48)
+              ENDIF
             ENDIF
           ENDIF
         ENDIF
