@@ -14,8 +14,10 @@ C
       YMAX = -BIG
 C
       NBON = 0
-      CACHPA = IFC.LT.0.OR.ISHRINK.LT.0.OR.ICOURB.LT.0.OR.I2D.NE.0
-     &     .OR.IPREFC.LT.0.OR.IFC.EQ.2
+      CACHPA = IFC.LT.0.OR.ISHRINK.LT.0
+     &     .OR.(ICOURB.LT.0.AND.ICOURXYZ.NE.2)
+     &     .OR.I2D.NE.0.OR.IORIENT.LT.0.OR.IFC.EQ.2
+cc     &     .OR.IPREFC.LT.0.OR.IFC.EQ.2
       SENS = REAL(ISENS)
       IF (NDS.EQ.3) THEN
         KMAX = 1
@@ -480,7 +482,7 @@ C
         CALL PROJEC(XC(I),YC(I),ZC(I),SENS,XBOITE(I),YBOITE(I)
      &             ,IPERSP,XPUP,DIST)
       ENDDO
-      END     
+      END
 C=======================================================================
       SUBROUTINE METLAPERSP
       INCLUDE 'com_options.f'
@@ -497,7 +499,7 @@ C
         XPUP(2) = DIST
         XPUP(3) = DIST
       ENDIF
-      END     
+      END
 C=======================================================================
       SUBROUTINE METLALIGHT
       INCLUDE 'com_faces.f'
