@@ -616,12 +616,21 @@ C
             ENDIF
             IF (ISO.EQ.0) THEN
               IF (ICTFAC.EQ.-1) THEN
-                CALL GSPAT(ICREF(NRFAC(NE)))
+                IF (IORIENT.LT.0) THEN
+                  IF (NSENS(NE).GT.0) THEN
+                    CALL GSPAT(4)
+                  ELSE
+                    CALL GSPAT(9)
+                  ENDIF
+                ELSE
+                  CALL GSPAT(ICREF(NRFAC(NE)))
+                ENDIF
               ELSEIF(ICTFAC.EQ.-2) THEN
                 NTEMP = MOD(ISD3(NE),16)
                 CALL GSPAT(ICREF(NTEMP))
               ELSEIF(ICTFAC.EQ.-3) THEN
                 NTEMP = MOD(ISD(NN),1000)
+                NTEMP = MOD(NTEMP,16)
                 CALL GSPAT(ICREF(NTEMP))
               ENDIF
               IF (ICTFAC.GT.15.AND.NDS.EQ.4) THEN
