@@ -173,7 +173,7 @@ C
       ENDIF
 C
 C Echelles x
-C 
+C
       YECH   = YMIMI - YBOX
       YECHL1 = YMIMI - YBOX*.6
       YECHL2 = YMIMI - YBOX*1.1
@@ -273,6 +273,22 @@ C
           LAX = .FALSE.
         ENDIF
       ENDIF
+C
+      JOUR = 0
+      MOIS = 0
+      IF (ITIMEX.LT.0.AND.ILOGX.GE.0) THEN
+        DO I=1,NDX
+          XS = REAL(XX(I))
+          IF (XS.GE.(XMIN-TY*.1) .AND. XS.LE.(XMAX+TY*.1) ) THEN
+            IF (LAX.OR.(LXX(I).AND.(ISAUTX.EQ.0.OR.IIMOD.GT.0))) THEN
+              CALL TRADHMS2(XX(I),CC,NC,ITIMEX)
+              IF (CC(1).NE.'0'.OR.CC(2).NE.'1'.OR.CC(3).NE.'/') JOUR = 1
+              IF (CC(4).NE.'0'.OR.CC(5).NE.'1'.OR.CC(6).NE.'/') MOIS = 1
+c              print*,(cc(k),k=1,nc),mois
+            ENDIF
+          ENDIF
+        ENDDO
+      ENDIF
 C
       DO 10 I=1,NDX
         XS = REAL(XX(I))
@@ -298,14 +314,27 @@ C
                 ENDIF
                 IF (ITIMEX.NE.0) THEN
                   CALL TRADHMS2(XTRAD,CC,NC,ITIMEX)
+                  IF (JOUR.EQ.0) THEN
+                    IF (MOIS.EQ.0) THEN
+                      DO K=1,NC-6
+                        CC(K) = CC(K+6)
+                      ENDDO
+                      NC = NC-6
+                    ELSE
+                      DO K=1,NC-3
+                        CC(K) = CC(K+3)
+                      ENDDO
+                      NC = NC-3
+                    ENDIF
+                  ENDIF
                   TAILL = TAILLE_CHAINE(CC,NC)
                 ELSE
                   CALL TRAD(XTRAD,CC,NC,XMIN,XMAX,IDECAL)
                   IF (IPUI.EQ.1.OR.ILOGPUI.EQ.1) THEN
                     CALL TRADVERIF(XTRAD,CC,NC,NC2,ILOGPUI,IRC)
                     IF (IRC.EQ.0) CALL TRAD2(CC,NC,NC2)
-                    TAILL1=TAILLE_CHAINE(CC,NC)
-                    TAILL2=TAILLE_CHAINE(CC(NC+1),NC2)*.45/.65
+                    TAILL1 = TAILLE_CHAINE(CC,NC)
+                    TAILL2 = TAILLE_CHAINE(CC(NC+1),NC2)*.45/.65
                   ELSE
                     TAILL = TAILLE_CHAINE(CC,NC)
                   ENDIF
