@@ -10,7 +10,7 @@ C http://www.cmap.polytechnique.fr/~jouve/xd3d
 C
       INCLUDE 'param.f'
 C
-      REAL*8  XX(NTMAX),YY(NTMAX)
+      REAL*8  XX(NTMAX),YY(NTMAX),XHMS
       INTEGER SAUVTABCO(256),NMARK1(NCMAX),NINTER(NCMAX)
       LOGICAL*4 LXX(NTMAX),LYY(NTMAX),WILD,SIGN,TROUVE,TRUE,FALSE
       CHARACTER*1   LEG(132,NCMAX)
@@ -635,7 +635,7 @@ C
         XMISAU = XMIN
         XMASAU = XMAX
       ENDIF
-      CALL ARONDI(XMIN,XMAX,XX,LXX,NDX,ILOGX,NTMAX,IARON,NDXMIN)
+      CALL ARONDI(XMIN,XMAX,XX,LXX,NDX,ILOGX,NTMAX,IARON,NDXMIN,ITIMEX)
       IF (NDX.GT.NDXMIN*3) THEN
         ISAUTX = 1
       ELSE
@@ -655,7 +655,7 @@ C
         YMISAU = YMIN
         YMASAU = YMAX
       ENDIF
-      CALL ARONDI(YMIN,YMAX,YY,LYY,NDY,ILOGY,NTMAX,IARON,NDXMIN)
+      CALL ARONDI(YMIN,YMAX,YY,LYY,NDY,ILOGY,NTMAX,IARON,NDXMIN,ITIMEY)
       IF (NDY.GT.NDXMIN*3) THEN
         ISAUTY = 1
       ELSE
@@ -1033,7 +1033,18 @@ CC      PRINT*,'Aprs ASREAD2',IIII,IPFK,ITYP,IBOUT
           ELSE
             YYYYY2 = YYYYY
           ENDIF
-          WRITE(CCOOR,'("("G13.5,","G13.5,")")') XXXXX2,YYYYY2
+          IF (ITIMEX.NE.0) THEN
+            XHMS = XXXXX2
+            IF (ITIMEX.GT.0) THEN
+              ITTT = ITIMEX
+            ELSE
+              ITTT = -2
+            ENDIF
+            CALL TRADHMS2(XHMS,CBID,NC,ITTT)
+            WRITE(CCOOR,'("(",A13,","G13.5,")")') CBID(1:NC),YYYYY2
+          ELSE
+            WRITE(CCOOR,'("(",G13.5,","G13.5,")")') XXXXX2,YYYYY2
+          ENDIF
         ELSE
           CCOOR = '                             '
         ENDIF
@@ -1770,7 +1781,7 @@ C
       ELSE
         NDXMIN = 50
       ENDIF
-      CALL ARONDI(XMIN,XMAX,XX,LXX,NDX,ILOGX,NTMAX,IARON,NDXMIN)
+      CALL ARONDI(XMIN,XMAX,XX,LXX,NDX,ILOGX,NTMAX,IARON,NDXMIN,ITIMEX)
       CALL BORNE
       IF (YMIN.EQ.YMAX) THEN
         YMIN=YMIN-0.5*(XMAX-XMIN)
