@@ -55,7 +55,7 @@ C
           READ(10,'(A1)') CC
         ENDDO
       ENDIF
-C 
+C
       NN  = 0
       NTROU(III) = 0
       NNN = 0
@@ -165,7 +165,7 @@ C
               NTROU(III) = NTROU(III)+1
               ITROU(NDEB(III)+NTROU(III)) = NN
             ENDIF
-          ELSE  
+          ELSE
             NTROU(III) = 1
             ITROU(NDEB(III)+1) = NN
           ENDIF
@@ -244,10 +244,10 @@ C
         IF (X.NE.0.) NTRONC = NTRONC+1
         XX = 0.
       ELSEIF(X.GT.XMAX) THEN
-        NTRONC = NTRONC+1 
+        NTRONC = NTRONC+1
         XX = REAL(XMAX)
       ELSEIF(X.LT.-XMAX) THEN
-        NTRONC = NTRONC+1 
+        NTRONC = NTRONC+1
         XX = -REAL(XMAX)
       ELSE
         XX = REAL(X)
@@ -653,10 +653,12 @@ C
       ENDIF
       IJ = NINT( (X-DBLE(IAN))*DBLE(365+IBI) )
       IMOIS = 0
-      DO WHILE(IJ.GT.0.AND.IMOIS.LT.12)
+      DO WHILE(IJ.GE.0.AND.IMOIS.LT.12)
         IMOIS = IMOIS+1
         IJ = IJ-LM(IMOIS)
         IF (IMOIS.EQ.2) IJ = IJ-IBI
       ENDDO
       IJOUR = IJ+LM(IMOIS)
+      IJOUR = MAX(1,IJOUR)
+      IMOIS = MAX(1,IMOIS)
       END
