@@ -496,6 +496,7 @@ C
      & ' -scat[=num] : points discrets (pas de traits entre les points)'
      & //' [pour la courbe num]'
               PRINT*,' -sky     : barres au lieu des courbes au trait'
+              PRINT*,' -speed=N : lecture d''un point sur N'
               PRINT*,' -square  : dessin carr'
               PRINT*,' -swap    : change des axes x et y'
               PRINT*,' -titgen="titre"  : titre gnral "titre"'
@@ -607,6 +608,7 @@ Cfj     & '**** NEW *** NEW *** NEW *** NEW *** NEW *** NEW *** NEW ****'
      & ' -scat[=num] : scatter points (no lines between points)'
      & //' [for plot number num]'
               PRINT*,' -sky     : bar chart'
+              PRINT*,' -speed=N : read 1 point every N'
               PRINT*,' -square  : square drawing'
               PRINT*,' -swap    : swap x and y axis'
               PRINT*,' -titgen="title"  : general title "title"'
