@@ -38,3 +38,13 @@ c
         enddo
       endif
       end
+c-----------------------------------------------------------------------
+      subroutine filtre_bad_char(cara,long)
+      character*1 cara(long)
+c
+      do i=1,long
+        ii = ichar(cara(i))
+        if ((ii.lt.32.and.ii.ne.9).or.ii.gt.126) cara(i) = ' '
+      enddo
+      end
+
